==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/content/common/content_message_generator.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Multiply-included file, hence no include guard.

#include "content/common/child_process_messages.h"

// NaCl's 64 bit Windows build only links with a bare-minimum number of
// libraries.
#if !defined(NACL_WIN64)
#include "content/common/appcache_messages.h"
#include "content/common/audio_messages.h"
#include "content/common/clipboard_messages.h"
#include "content/common/database_messages.h"
#include "content/common/desktop_notification_messages.h"
#include "content/common/device_orientation_messages.h"
#include "content/common/devtools_messages.h"
#include "content/common/dom_storage_messages.h"
#include "content/common/drag_messages.h"
#include "content/common/file_system_messages.h"
#include "content/common/file_utilities_messages.h"
#include "content/common/geolocation_messages.h"
#include "content/common/gpu/gpu_messages.h"
#include "content/common/indexed_db_messages.h"
#include "content/common/mime_registry_messages.h"
#include "content/common/p2p_messages.h"
#include "content/common/pepper_file_messages.h"
#include "content/common/plugin_messages.h"
#include "content/common/quota_messages.h"
#include "content/common/resource_messages.h"
#include "content/common/speech_input_messages.h"
#include "content/common/socket_stream_messages.h"
#include "content/common/video_capture_messages.h"
#include "content/common/view_messages.h"
#include "content/common/webblob_messages.h"
#include "content/common/worker_messages.h"
#endif

==> chromium-browser_14.0.835.202~r103287.orig.tar.bz2: chromium-14.0.835.202~r103287/src/content/common/content_message_generator.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Multiply-included file, hence no include guard.

#include "content/common/child_process_messages.h"

// NaCl's 64 bit Windows build only links with a bare-minimum number of
// libraries.
#if !defined(NACL_WIN64)
#include "content/common/appcache_messages.h"
#include "content/common/clipboard_messages.h"
#include "content/common/database_messages.h"
#include "content/common/desktop_notification_messages.h"
#include "content/common/device_orientation_messages.h"
#include "content/common/devtools_messages.h"
#include "content/common/dom_storage_messages.h"
#include "content/common/drag_messages.h"
#include "content/common/file_system_messages.h"
#include "content/common/file_utilities_messages.h"
#include "content/common/geolocation_messages.h"
#include "content/common/gpu/gpu_messages.h"
#include "content/common/indexed_db_messages.h"
#include "content/common/media/audio_messages.h"
#include "content/common/media/media_stream_messages.h"
#include "content/common/media/video_capture_messages.h"
#include "content/common/mime_registry_messages.h"
#include "content/common/p2p_messages.h"
#include "content/common/pepper_file_messages.h"
#include "content/common/plugin_messages.h"
#include "content/common/quota_messages.h"
#include "content/common/resource_messages.h"
#include "content/common/speech_input_messages.h"
#include "content/common/socket_stream_messages.h"
#include "content/common/utility_messages.h"
#include "content/common/view_messages.h"
#include "content/common/webblob_messages.h"
#include "content/common/worker_messages.h"
#endif
